/*
 * Copyright (C) 2017 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.build.gradle.internal.api.dsl.model

import com.android.build.api.dsl.model.BuildType
import com.android.build.gradle.internal.api.dsl.DslScope
import org.gradle.api.NamedDomainObjectFactory

class BuildTypeFactory(
            private val dslScope: DslScope)
        : NamedDomainObjectFactory<BuildType> {

    override fun create(name: String): BuildType {
        val buildTypeOrVariant = BuildTypeOrVariantImpl("BuildType", dslScope)

        return dslScope.objectFactory.newInstance(BuildTypeImpl::class.java,
                name,
                VariantPropertiesImpl(dslScope),
                BuildTypeOrProductFlavorImpl(dslScope, { buildTypeOrVariant.postProcessing }),
                buildTypeOrVariant,
                FallbackStrategyImpl(dslScope),
                dslScope)
    }
}
