/*
 * Copyright (C) 2018 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
@file:JvmName("CrashReporting")

package com.android.build.gradle.internal.crash

import org.gradle.api.Action
import org.gradle.api.Project
import java.util.function.Consumer

/** Runs the specified Runnable and reports exception. */
fun runAction(c: Runnable) {
    try {
        c.run()
    } catch (t: Throwable) {
        PluginCrashReporter.maybeReportException(t)
        throw t
    }
}

fun afterEvaluate(c: Consumer<Project>): Action<in Project> {
    return Action { project: Project ->
        try {
            c.accept(project)
        } catch (t: Throwable) {
            PluginCrashReporter.maybeReportException(t)
            throw t
        }
    }
}